==> haskell-versions-6.0.8-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 versions
version:              6.0.8
visibility:           public
id:                   versions-6.0.8-6gQi2hP0iSb2BdtaDbUWZE
key:                  versions-6.0.8-6gQi2hP0iSb2BdtaDbUWZE
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  f5f680540f1130d5e90b91523471d782
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-versions
hs-libraries:         HSversions-6.0.8-6gQi2hP0iSb2BdtaDbUWZE
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-HCL6HYi7vZb6weAXUagHtJ
    megaparsec-9.6.1-EACNQE4V0s4sorPNkNSJS
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-versions-6.0.8-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-versions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 versions
version:              6.0.8
visibility:           public
id:                   versions-6.0.8-2ClCOofa1OQBa7QTjLGT85
key:                  versions-6.0.8-2ClCOofa1OQBa7QTjLGT85
license:              BSD-3-Clause
maintainer:           colin@fosskers.ca
author:               Colin Woodbury
homepage:             https://github.com/fosskers/versions
synopsis:             Types and parsers for software version numbers.
description:
    A library for parsing and comparing software version numbers. We like to give
    version numbers to our software in a myriad of ways. Some ways follow strict
    guidelines for incrementing and comparison. Some follow conventional wisdom
    and are generally self-consistent. Some are just plain asinine. This library
    provides a means of parsing and comparing /any/ style of versioning, be it a
    nice Semantic Version like this:

    > 1.2.3-r1+git123

    ...or a monstrosity like this:

    > 2:10.2+0.0093r3+1-1

    Please switch to <http://semver.org Semantic Versioning> if you aren'\''t
    currently using it. It provides consistency in version incrementing and has
    the best constraints on comparisons.

    This library implements version @2.0.0@ of the SemVer spec.

category:             Data
abi:                  75556b7d1106908bb601a17bc54e61dd
exposed:              True
exposed-modules:      Data.Versions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/versions-6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-versions
hs-libraries:         HSversions-6.0.8-2ClCOofa1OQBa7QTjLGT85
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.4.0-C1fFIG7AZLC7j0jzLm97Uw
    megaparsec-9.6.1-EEBj4pRLerNCeJDumClMn7
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    template-haskell-2.19.0.0 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-versions/html/versions.haddock
haddock-html:         /usr/share/doc/haskell-versions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
